==> camitk_3.2.2.orig.tar.gz: camitk-3.2.2-Source/sdk/actions/application/ClearSelectionAction.h <==
/*****************************************************************************
 * $CAMITK_LICENCE_BEGIN$
 *
 * CamiTK - Computer Assisted Medical Intervention ToolKit
 * (c) 2001-2013 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
 *
 * Visit http://camitk.imag.fr for more information
 *
 * This file is part of CamiTK.
 *
 * CamiTK is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * CamiTK is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with CamiTK.  If not, see <http://www.gnu.org/licenses/>.
 *
 * $CAMITK_LICENCE_END$
 ****************************************************************************/

#ifndef CLEARSELECTION_ACTION_H
#define CLEARSELECTION_ACTION_H

#include <Action.h>

class ClearSelectionAction : public camitk::Action {

public:
  /// Default Constructor
  ClearSelectionAction(camitk::ActionExtension *);

  /// Default Destructor
  virtual ~ClearSelectionAction();

  /// Returns NULL: no widget at all for this action
  virtual QWidget * getWidget();

public slots:
  /// apply the action select the last instanciated component
  virtual ApplyStatus apply();

};
#endif // CLEARSELECTION_ACTION_H

==> camitk_3.3.2.orig.tar.gz: camitk-3.3.2-Source/sdk/actions/application/ClearSelectionAction.h <==
/*****************************************************************************
 * $CAMITK_LICENCE_BEGIN$
 *
 * CamiTK - Computer Assisted Medical Intervention ToolKit
 * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
 *
 * Visit http://camitk.imag.fr for more information
 *
 * This file is part of CamiTK.
 *
 * CamiTK is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * CamiTK is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with CamiTK.  If not, see <http://www.gnu.org/licenses/>.
 *
 * $CAMITK_LICENCE_END$
 ****************************************************************************/

#ifndef CLEARSELECTION_ACTION_H
#define CLEARSELECTION_ACTION_H

#include <Action.h>

/**
 * @ingroup group_sdk_actions_application
 * 
 * @brief 
 * The ClearSelectionAction allows user to clear the selected components in the components explorer.
 * 
 **/
class ClearSelectionAction : public camitk::Action {

public:
  /// Default Constructor
  ClearSelectionAction(camitk::ActionExtension *);

  /// Default Destructor
  virtual ~ClearSelectionAction();

  /// Returns NULL: no widget at all for this action
  virtual QWidget * getWidget();

public slots:
  /// apply the action select the last instanciated component
  virtual ApplyStatus apply();

};
#endif // CLEARSELECTION_ACTION_H
